@@ -86,7 +86,6 @@ send back the CSRF token in the custom X-CSRFTOKEN header:
 
 """
 from shake import redirect, NotAllowed, url_for, get_csrf
-from werkzeug.exceptions import HTTPException
 
 
 __all__ = (
@@ -164,15 +163,9 @@ def is_valid(request, csrf=True):
 
 def invalid_csrf(request):
     valid_csrf_token = get_csrf(request)
-    try:
-        csrf_token = request.values.get(
-            valid_csrf_token.name,
-            request.headers.get('X-CSRFToken'))
-    except HTTPException, e:
-        try:
-            csrf_token = request.headers.get('X-CSRFToken')
-        except HTTPException, e:
-            return True
+    csrf_token = request.values.get(
+        valid_csrf_token.name,
+        request.headers.get('X-CSRFToken'))
     return csrf_token != valid_csrf_token.value
 
 invalid_csrf_secret = invalid_csrf
